// Copyright (C) 2009-2010 Ferdinand Majerech
// This file is part of MiniINI
// For conditions of distribution and use, see copyright notice in LICENSE.txt

#ifndef INI_H_INCLUDED
#define INI_H_INCLUDED

#include "typedefs.h"
#include "inisection.h" 

///INI File class
/*
 * Reads and stores data from an ini file and gives access to its sections.
 */
class INIFile
{
    private:

        ///Number of sections in the file.
        miniini_private::ui Length;
        ///Array of pointers to sections.
        INISection * * Sections;

    public:

        ///Empty constructor.
        INIFile();

        ///Loads given INI file. 
        /**
         * @param fname Filename of the file to load. Must be a valid, zero terminated string. 
         * @return true if the file is succesfully loaded.
         * @return false if the file does not exist, can not be accessed or is otherwise invalid.
         */
        bool OpenFile(const char * const fname);

        ///Destructor.
        /**
         * Deletes loaded INI file (if any)
         */
        ~INIFile();

        ///Gets pointer to requested section.
        /**
         * @param name Name of the section to get. Must be a valid, zero terminated string.
         * @return pointer to requested section if the section exists.
         * @return NULL if the section does not exist.
         */
        INISection * GetSection(const char * const name) const;

        ///[] operator : alias for GetSection().
        /**
         * @param name Name of the section to get. Must be a valid, zero terminated string.
         * @return pointer to requested section if the section exists.
         * @return NULL if the section does not exist.
         */
        INISection * operator [] (const char * const name) const;

        ///@return number of sections in the file.
        unsigned GetLength() const;
        
    private:

        INIFile(const INIFile &);

        void operator = (const INIFile &);

};

#endif 
